[![Netlify Status](https://api.netlify.com/api/v1/badges/78c3cc1a-7565-4d00-9f0c-45f0452d41ed/deploy-status)](https://app.netlify.com/sites/ai-speaker/deploys)

# AI-Speaker Frontend

This is the repository for the official [AI-Speaker](https://ai-speaker.com) frontend.

## License

Home Assistant is open-source and Apache 2 licensed. Feel free to browse the repository, learn and reuse parts in your own projects.

We use [BrowserStack](https://www.browserstack.com) to test Home Assistant on a large variety of devices.
